==> minorminer-0.1.9.tar.gz: minorminer-0.1.9/setup.py <==
from setuptools import setup, extension
from setuptools.command.build_ext import build_ext
import sys
import os
import platform
cwd = os.path.abspath(os.path.dirname(__file__))

if not os.path.exists(os.path.join(cwd, 'PKG-INFO')):
    try:
        from Cython.Build import cythonize
        USE_CYTHON = True
    except ImportError:
        USE_CYTHON = False
else:
    USE_CYTHON = False

_PY2 = sys.version_info.major == 2

# Change directories so this works when called from other locations. Useful in build systems that build from source.
setup_folder_loc = os.path.dirname(os.path.abspath(__file__))
os.chdir(setup_folder_loc)

# Add __version__, __author__, __authoremail__, __description__ to this namespace
path_to_package_info = os.path.join('.', 'minorminer', 'package_info.py')
if _PY2:
    execfile(path_to_package_info)
else:
    exec(open(path_to_package_info).read())

extra_compile_args = {
    'msvc': ['/std:c++latest', '/MT', '/EHsc'],
    'unix': ['-std=c++11', '-Wextra', '-Wno-format-security', '-Ofast', '-fomit-frame-pointer', '-DNDEBUG', '-fno-rtti'],
}

extra_link_args = {
    'msvc': [],
    'unix': ['-std=c++11'],
}

if '--debug' in sys.argv or '-g' in sys.argv or 'CPPDEBUG' in os.environ:
    extra_compile_args['msvc'].append('/DCPPDEBUG')
    extra_compile_args['unix'] = ['-std=c++1y', '-w',
                                  '-O0', '-g', '-fipa-pure-const', '-DCPPDEBUG']


class build_ext_compiler_check(build_ext):
    def build_extensions(self):
        compiler = self.compiler.compiler_type

        compile_args = extra_compile_args[compiler]
        for ext in self.extensions:
            ext.extra_compile_args = compile_args

        link_args = extra_compile_args[compiler]
        for ext in self.extensions:
            ext.extra_compile_args = link_args

        build_ext.build_extensions(self)


class Extension(extension.Extension, object):
    pass


ext = '.pyx' if USE_CYTHON else '.cpp'

extensions = [Extension(
    name="minorminer._minorminer",
    sources=["./minorminer/_minorminer" + ext],
    include_dirs=['', './include/'],
    language='c++',
)]

if USE_CYTHON:
    extensions = cythonize(extensions)

os.environ["MACOSX_DEPLOYMENT_TARGET"] = platform.mac_ver()[0]

classifiers = [
    'License :: OSI Approved :: Apache Software License',
    'Operating System :: OS Independent',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
]

python_requires = '>=2.7,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*'

setup(
    name="minorminer",
    description=__description__,
    long_description="minorminer is a tool for finding graph minors, developed to embed Ising problems onto quantum annealers (QA). Where it can be used to find minors in arbitrary graphs, it is particularly geared towards the state of the art in QA: problem graphs of a few to a few hundred variables, and hardware graphs of a few thousand qubits.",
    author=__author__,
    author_email=__authoremail__,
    url="https://github.com/dwavesystems/minorminer",
    version=__version__,
    license="Apache 2.0",
    ext_modules=extensions,
    packages=['minorminer'],
    classifiers=classifiers,
    python_requires=python_requires,
    cmdclass={'build_ext': build_ext_compiler_check}
)

==> minorminer-0.2.0.dev1.tar.gz: minorminer-0.2.0.dev1/setup.py <==
from setuptools import setup, extension
from setuptools.command.build_ext import build_ext
import sys
import os
import platform
cwd = os.path.abspath(os.path.dirname(__file__))

if not os.path.exists(os.path.join(cwd, 'PKG-INFO')):
    try:
        from Cython.Build import cythonize
        USE_CYTHON = True
    except ImportError:
        USE_CYTHON = False
else:
    USE_CYTHON = False

_PY2 = sys.version_info.major == 2

# Change directories so this works when called from other locations. Useful in build systems that build from source.
setup_folder_loc = os.path.dirname(os.path.abspath(__file__))
os.chdir(setup_folder_loc)

# Add __version__, __author__, __authoremail__, __description__ to this namespace
path_to_package_info = os.path.join('.', 'minorminer', 'package_info.py')
if _PY2:
    execfile(path_to_package_info)
else:
    exec(open(path_to_package_info).read())

extra_compile_args = {
    'msvc': {
        'c++': ['/std:c++latest', '/MT', '/EHsc'],
        'c': [],
    },
    'unix': {
        'c++': ['-std=c++11', '-Wall', '-Wno-format-security', '-Ofast', '-fomit-frame-pointer', '-DNDEBUG', '-fno-rtti'],
        'c': ['-std=c99', '-Wall', '-Wno-format-security', '-Ofast', '-fomit-frame-pointer', '-DNDEBUG'],
    },
}

extra_link_args = {
    'msvc': {'c++': [], 'c': []},
    'unix': {
        'c++': ['-std=c++11'],
        'c': ['-std=c99'],
    },
}


if '--debug' in sys.argv or '-g' in sys.argv or 'CPPDEBUG' in os.environ:
    extra_compile_args['msvc']['c++'].append('/DCPPDEBUG')
    extra_compile_args['unix']['c++'] = ['-std=c++1y', '-Wall',
                                  '-O0', '-g', '-fipa-pure-const', '-DCPPDEBUG']
    extra_compile_args['unix']['c'] = ['-std=c99', '-Wall',
                                  '-O0', '-g', '-fipa-pure-const', '-DCPPDEBUG']


class build_ext_compiler_check(build_ext):
    def build_extensions(self):
        compiler = self.compiler.compiler_type

        compile_args = extra_compile_args[compiler]
        for ext in self.extensions:
            ext.extra_compile_args = compile_args[ext.language]

        link_args = extra_link_args[compiler]
        for ext in self.extensions:
            ext.extra_link_args = link_args[ext.language]

        build_ext.build_extensions(self)


class Extension(extension.Extension, object):
    pass


ext = '.pyx' if USE_CYTHON else '.cpp'

extensions = [
    Extension(
        name="minorminer._minorminer",
        sources=["./minorminer/_minorminer" + ext],
        include_dirs=['', './include/', './include/find_embedding'],
        language='c++',
    ),
    Extension(
        name="minorminer.busclique",
        sources=["./minorminer/busclique" + ext],
        include_dirs=['', './include/', '.include/busclique'],
        language='c++',
    ),
]

if USE_CYTHON:
    extensions = cythonize(extensions)

#borrowed from rectangle-packer
extensions.append(
    Extension('minorminer._rpack',
              sources=['rectangle-packer/src/rpack.c',
                       'rectangle-packer/src/areapack.c',
                       'rectangle-packer/src/taskpack.c'],
              include_dirs=['rectangle-packer/include'],
              language='c')
)

os.environ["MACOSX_DEPLOYMENT_TARGET"] = platform.mac_ver()[0]

classifiers = [
    'License :: OSI Approved :: Apache Software License',
    'Operating System :: OS Independent',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
]

python_requires = '>=3.5'
install_requires = [
    "scipy", "networkx", "dwave-networkx", "numpy"
]

setup(
    name="minorminer",
    description=__description__,
    long_description="minorminer is a tool for finding graph minors, developed to embed Ising problems onto quantum annealers (QA). Where it can be used to find minors in arbitrary graphs, it is particularly geared towards the state of the art in QA: problem graphs of a few to a few hundred variables, and hardware graphs of a few thousand qubits.",
    author=__author__,
    author_email=__authoremail__,
    url="https://github.com/dwavesystems/minorminer",
    version=__version__,
    license="Apache 2.0",
    ext_modules=extensions,
    packages=['minorminer',
              'minorminer.layout'],
    classifiers=classifiers,
    python_requires=python_requires,
    install_requires=install_requires,
    cmdclass={'build_ext': build_ext_compiler_check}
)
